//////////////////////////////////////////////////////////////////////////////////////////////
// Copyright 2016 Leszek Koltunski                                                          //
//                                                                                          //
// This file is part of Distorted.                                                          //
//                                                                                          //
// Distorted is free software: you can redistribute it and/or modify                        //
// it under the terms of the GNU General Public License as published by                     //
// the Free Software Foundation, either version 2 of the License, or                        //
// (at your option) any later version.                                                      //
//                                                                                          //
// Distorted is distributed in the hope that it will be useful,                             //
// but WITHOUT ANY WARRANTY; without even the implied warranty of                           //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                            //
// GNU General Public License for more details.                                             //
//                                                                                          //
// You should have received a copy of the GNU General Public License                        //
// along with Distorted.  If not, see <http://www.gnu.org/licenses/>.                       //
//////////////////////////////////////////////////////////////////////////////////////////////

precision mediump float;

#if __VERSION__ != 100
in vec3 v_Position;                     // Interpolated position for this fragment.
in vec3 v_Normal;                       // Interpolated normal for this fragment.
in vec2 v_TexCoordinate;                // Interpolated texture coordinate per fragment.
out vec4 fragColor;                     // The output color
#define TEXTURE texture
#define FRAG_COLOR fragColor
#else
varying vec3 v_Position;                // Interpolated position for this fragment.
varying vec3 v_Normal;                  // Interpolated normal for this fragment.
varying vec2 v_TexCoordinate;           // Interpolated texture coordinate per fragment.
#define TEXTURE texture2D
#define FRAG_COLOR gl_FragColor
#endif

uniform sampler2D u_Texture;            // The input texture.

#if NUM_FRAGMENT>0
uniform int fNumEffects;                // total number of fragment effects
uniform int fName[NUM_FRAGMENT];        // their namess.
uniform vec4 fUniforms[2*NUM_FRAGMENT]; // i-th effect is 2 consecutive vec4's: [2*i], [2*i+1]. First vec4 is the Interpolated values,
                                        // next describes the Region, i.e. area over which the effect is active.
#endif    // NUM_FRAGMENT>0

//////////////////////////////////////////////////////////////////////////////////////////////

void main()                    		
  {  
  vec4 color = TEXTURE(u_Texture,v_TexCoordinate);

#if NUM_FRAGMENT>0
  vec2 diff;
  float degree;
  int effect=0;

  for(int i=0; i<fNumEffects; i++)
    {
    diff   = (v_Position.xy - fUniforms[effect+1].xy)/fUniforms[effect+1].zw;
    degree = max(0.0,1.0-dot(diff,diff));

    // ENABLED EFFECTS WILL BE INSERTED HERE

    effect+=2;
    }
#endif

  FRAG_COLOR = vec4(color.rgb * (1.0 + 7.0*v_Normal.z) * 0.125, color.a);
  }